summaryrefslogtreecommitdiffstats
path: root/kdat/InfoShellWidget.h
diff options
context:
space:
mode:
Diffstat (limited to 'kdat/InfoShellWidget.h')
-rw-r--r--kdat/InfoShellWidget.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/kdat/InfoShellWidget.h b/kdat/InfoShellWidget.h
index ae8dd90..0f87585 100644
--- a/kdat/InfoShellWidget.h
+++ b/kdat/InfoShellWidget.h
@@ -22,7 +22,7 @@
#include <tqwidget.h>
/**
* @short A suitable tqparent for the info widgets.
*/
class InfoShellWidget : public TQWidget {
Q_OBJECT
@@ -31,10 +31,10 @@ public:
/**
* Create a new info shell widget.
*
* @param tqparent The tqparent widget.
* @param name The name of this widget.
*/
- InfoShellWidget( TQWidget* tqparent = 0, const char* name = 0 );
+ InfoShellWidget( TQWidget* parent = 0, const char* name = 0 );
/**
* Destroy the info shell widget.
@@ -22,7 +22,7 @@
#include <tqwidget.h>
/**
- * @short A suitable tqparent for the info widgets.
+ * @short A suitable parent for the info widgets.
*/
class InfoShellWidget : public TQWidget {
@@ -31,10 +31,10 @@ public:
* Create a new info shell widget.
*
- * @param tqparent The tqparent widget.
+ * @param parent The parent widget.
* @param name The name of this widget.
*/